==> checkstyle-3.4-sources.jar: hudson/plugins/checkstyle/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.checkstyle;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Checkstyle warnings per project
     * 
     */
    public static String Portlet_WarningsTable() {
        return holder.format("Portlet.WarningsTable");
    }

    /**
     * Checkstyle warnings per project
     * 
     */
    public static Localizable _Portlet_WarningsTable() {
        return new Localizable(holder, "Portlet.WarningsTable");
    }

    /**
     * Checkstyle: {0} warnings found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("Checkstyle.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Checkstyle: {0} warnings found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * from one Checkstyle file.
     * 
     */
    public static String Checkstyle_ResultAction_OneFile() {
        return holder.format("Checkstyle.ResultAction.OneFile");
    }

    /**
     * from one Checkstyle file.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneFile() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneFile");
    }

    /**
     * Publish Checkstyle analysis results
     * 
     */
    public static String Checkstyle_Publisher_Name() {
        return holder.format("Checkstyle.Publisher.Name");
    }

    /**
     * Publish Checkstyle analysis results
     * 
     */
    public static Localizable _Checkstyle_Publisher_Name() {
        return new Localizable(holder, "Checkstyle.Publisher.Name");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String Checkstyle_ResultAction_OneFixedWarning() {
        return holder.format("Checkstyle.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneFixedWarning");
    }

    /**
     * Checkstyle Trend
     * 
     */
    public static String Checkstyle_Trend_Name() {
        return holder.format("Checkstyle.Trend.Name");
    }

    /**
     * Checkstyle Trend
     * 
     */
    public static Localizable _Checkstyle_Trend_Name() {
        return new Localizable(holder, "Checkstyle.Trend.Name");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static String Checkstyle_Detail_header() {
        return holder.format("Checkstyle.Detail.header");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_Detail_header() {
        return new Localizable(holder, "Checkstyle.Detail.header");
    }

    /**
     * Checkstyle: no warnings found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportNoItem() {
        return holder.format("Checkstyle.ResultAction.HealthReportNoItem");
    }

    /**
     * Checkstyle: no warnings found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportNoItem");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static String Checkstyle_ProjectAction_Name() {
        return holder.format("Checkstyle.ProjectAction.Name");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_ProjectAction_Name() {
        return new Localizable(holder, "Checkstyle.ProjectAction.Name");
    }

    /**
     *  1 new warning
     * 
     */
    public static String Checkstyle_ResultAction_OneNewWarning() {
        return holder.format("Checkstyle.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneNewWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneNewWarning");
    }

    /**
     * New Checkstyle Warnings
     * 
     */
    public static String Checkstyle_NewWarnings_Detail_header() {
        return holder.format("Checkstyle.NewWarnings.Detail.header");
    }

    /**
     * New Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_NewWarnings_Detail_header() {
        return new Localizable(holder, "Checkstyle.NewWarnings.Detail.header");
    }

    /**
     *  1 warning
     * 
     */
    public static String Checkstyle_ResultAction_OneWarning() {
        return holder.format("Checkstyle.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneWarning");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * from {0} Checkstyle files.
     * 
     */
    public static String Checkstyle_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleFiles", arg1);
    }

    /**
     * from {0} Checkstyle files.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleFiles", arg1);
    }

    /**
     * Checkstyle: one warning found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportSingleItem() {
        return holder.format("Checkstyle.ResultAction.HealthReportSingleItem");
    }

    /**
     * Checkstyle: one warning found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportSingleItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * Fixed Checkstyle Warnings
     * 
     */
    public static String Checkstyle_FixedWarnings_Detail_header() {
        return holder.format("Checkstyle.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_FixedWarnings_Detail_header() {
        return new Localizable(holder, "Checkstyle.FixedWarnings.Detail.header");
    }

}

==> checkstyle-3.12-sources.jar: hudson/plugins/checkstyle/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.checkstyle;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Checkstyle warnings trend graph (new vs. fixed)
     * 
     */
    public static String Portlet_WarningsNewVsFixedGraph() {
        return holder.format("Portlet.WarningsNewVsFixedGraph");
    }

    /**
     * Checkstyle warnings trend graph (new vs. fixed)
     * 
     */
    public static Localizable _Portlet_WarningsNewVsFixedGraph() {
        return new Localizable(holder, "Portlet.WarningsNewVsFixedGraph");
    }

    /**
     * Checkstyle warnings per project
     * 
     */
    public static String Portlet_WarningsTable() {
        return holder.format("Portlet.WarningsTable");
    }

    /**
     * Checkstyle warnings per project
     * 
     */
    public static Localizable _Portlet_WarningsTable() {
        return new Localizable(holder, "Portlet.WarningsTable");
    }

    /**
     * Checkstyle: {0} warnings found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("Checkstyle.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Checkstyle: {0} warnings found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * from one Checkstyle file.
     * 
     */
    public static String Checkstyle_ResultAction_OneFile() {
        return holder.format("Checkstyle.ResultAction.OneFile");
    }

    /**
     * from one Checkstyle file.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneFile() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneFile");
    }

    /**
     * Publish Checkstyle analysis results
     * 
     */
    public static String Checkstyle_Publisher_Name() {
        return holder.format("Checkstyle.Publisher.Name");
    }

    /**
     * Publish Checkstyle analysis results
     * 
     */
    public static Localizable _Checkstyle_Publisher_Name() {
        return new Localizable(holder, "Checkstyle.Publisher.Name");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String Checkstyle_ResultAction_OneFixedWarning() {
        return holder.format("Checkstyle.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneFixedWarning");
    }

    /**
     * Checkstyle Trend
     * 
     */
    public static String Checkstyle_Trend_Name() {
        return holder.format("Checkstyle.Trend.Name");
    }

    /**
     * Checkstyle Trend
     * 
     */
    public static Localizable _Checkstyle_Trend_Name() {
        return new Localizable(holder, "Checkstyle.Trend.Name");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static String Checkstyle_Detail_header() {
        return holder.format("Checkstyle.Detail.header");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_Detail_header() {
        return new Localizable(holder, "Checkstyle.Detail.header");
    }

    /**
     * Checkstyle: no warnings found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportNoItem() {
        return holder.format("Checkstyle.ResultAction.HealthReportNoItem");
    }

    /**
     * Checkstyle: no warnings found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportNoItem");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static String Checkstyle_ProjectAction_Name() {
        return holder.format("Checkstyle.ProjectAction.Name");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_ProjectAction_Name() {
        return new Localizable(holder, "Checkstyle.ProjectAction.Name");
    }

    /**
     *  1 new warning
     * 
     */
    public static String Checkstyle_ResultAction_OneNewWarning() {
        return holder.format("Checkstyle.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneNewWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneNewWarning");
    }

    /**
     * New Checkstyle Warnings
     * 
     */
    public static String Checkstyle_NewWarnings_Detail_header() {
        return holder.format("Checkstyle.NewWarnings.Detail.header");
    }

    /**
     * New Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_NewWarnings_Detail_header() {
        return new Localizable(holder, "Checkstyle.NewWarnings.Detail.header");
    }

    /**
     * Checkstyle warnings trend graph (priority distribution)
     * 
     */
    public static String Portlet_WarningsPriorityGraph() {
        return holder.format("Portlet.WarningsPriorityGraph");
    }

    /**
     * Checkstyle warnings trend graph (priority distribution)
     * 
     */
    public static Localizable _Portlet_WarningsPriorityGraph() {
        return new Localizable(holder, "Portlet.WarningsPriorityGraph");
    }

    /**
     *  1 warning
     * 
     */
    public static String Checkstyle_ResultAction_OneWarning() {
        return holder.format("Checkstyle.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneWarning");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * from {0} Checkstyle files.
     * 
     */
    public static String Checkstyle_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleFiles", arg1);
    }

    /**
     * from {0} Checkstyle files.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleFiles", arg1);
    }

    /**
     * Checkstyle: one warning found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportSingleItem() {
        return holder.format("Checkstyle.ResultAction.HealthReportSingleItem");
    }

    /**
     * Checkstyle: one warning found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportSingleItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * Fixed Checkstyle Warnings
     * 
     */
    public static String Checkstyle_FixedWarnings_Detail_header() {
        return holder.format("Checkstyle.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_FixedWarnings_Detail_header() {
        return new Localizable(holder, "Checkstyle.FixedWarnings.Detail.header");
    }

}
